@@ -1,6 +1,6 @@
 from caribou.settings.preferences_window import PreferencesDialog
 from caribou.settings import CaribouSettings
-from antler_settings import AntlerSettings
+from .antler_settings import AntlerSettings
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GObject
@@ -193,7 +193,7 @@ class AntlerLayout(Gtk.Box):
 
             for i, key in enumerate(col):
                 align = key.props.align
-                if not alignboxes.has_key(align):
+                if align not in alignboxes:
                     alignbox = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
                     alignbox.set_spacing(self._spacing)
                     alignboxes[align] = alignbox
@@ -215,7 +215,8 @@ class AntlerLayout(Gtk.Box):
             self.add_row([c.get_children() for c in row.get_columns()], row_num)
 
 class AntlerKeyboardView(Gtk.Notebook):
-    def __init__(self, keyboard_type):
+    def __init__(self, keyboard_type='touch', keyboard_file=None,
+                 keyboard_level=None):
         GObject.GObject.__init__(self)
         settings = AntlerSettings()
         self.set_show_tabs(False)
@@ -244,10 +245,11 @@ class AntlerKeyboardView(Gtk.Notebook):
                 Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION + 1)
 
         self.scanner = Caribou.Scanner()
-        self.set_keyboard_model(keyboard_type)
+        self.set_keyboard_model(keyboard_type, keyboard_file, keyboard_level)
 
-    def set_keyboard_model(self, keyboard_type):
-        self.keyboard_model = Caribou.KeyboardModel(keyboard_type=keyboard_type)
+    def set_keyboard_model(self, keyboard_type, keyboard_file, keyboard_level):
+        self.keyboard_model = Caribou.KeyboardModel(keyboard_type=keyboard_type,
+                                                    keyboard_file=keyboard_file)
 
         self.scanner.set_keyboard(self.keyboard_model)
         self.keyboard_model.connect("notify::active-group", self._on_group_changed)
@@ -265,7 +267,7 @@ class AntlerKeyboardView(Gtk.Notebook):
                 layout.show()
                 self.layers[gname][lname] = self.append_page(layout, None)
 
-        self._set_to_active_layer()
+        self._set_to_active_layer(keyboard_level=keyboard_level)
 
     def _on_key_clicked(self, model, key):
         if key.props.name == "Caribou_Prefs":
@@ -286,7 +288,7 @@ class AntlerKeyboardView(Gtk.Notebook):
 
     def _load_style(self, provider, filename, search_path):
         spath = search_path[:]
-        if os.environ.has_key("ANTLER_THEME_PATH"):
+        if "ANTLER_THEME_PATH" in os.environ:
             spath.insert(0, os.environ["ANTLER_THEME_PATH"])
 
         for directory in spath:
@@ -301,10 +303,13 @@ class AntlerKeyboardView(Gtk.Notebook):
     def _on_group_changed(self, kb, prop):
         self._set_to_active_layer()
 
-    def _set_to_active_layer(self):
+    def _set_to_active_layer(self, keyboard_level=None):
         active_group_name = self.keyboard_model.props.active_group
         active_group = self.keyboard_model.get_group(active_group_name)
-        active_level_name = active_group.props.active_level
+        if keyboard_level:
+            active_level_name = keyboard_level
+        else:
+            active_level_name = active_group.props.active_level
 
         self.set_current_page(self.layers[active_group_name][active_level_name])
 
